From 49dfb0047a53758a3e12699cf6e0b4da55aefd3e Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Sat, 23 May 2009 10:17:07 -0400
Subject: [PATCH] - Added message menu (some image needed), removed Print and Source buttons - Added possibility to save message as .eml file (#1485861)

---
 program/include/rcube_template.php |   19 ++++++++++---------
 1 files changed, 10 insertions(+), 9 deletions(-)

diff --git a/program/include/rcube_template.php b/program/include/rcube_template.php
index 1a83e5c..b597c55 100755
--- a/program/include/rcube_template.php
+++ b/program/include/rcube_template.php
@@ -338,9 +338,12 @@
         if (count($temp) > 1) {
             $plugin = $temp[0];
             $name = $temp[1];
-            $skin_path = $this->config['plugins_dir'] . '/' . $temp[0] . '/skins/' . $this->config['skin'];
-            if (!is_dir($skin_path))  // fallback to default skin
-                $skin_path = $this->config['plugins_dir'] . '/' . $temp[0] . '/skins/default';
+            $skin_dir = $plugin . '/skins/' . $this->config['skin'];
+            $skin_path = $this->config['plugins_dir'] . '/' . $skin_dir;
+            if (!is_dir($skin_path)) {  // fallback to default skin
+                $skin_dir = $plugin . '/skins/default';
+                $skin_path = $this->config['plugins_dir'] . '/' . $skin_dir;
+            }
         }
         
         $path = "$skin_path/templates/$name.html";
@@ -357,9 +360,10 @@
             return false;
         }
         
         // replace all path references to plugins/... with the current plugins dir
         if ($plugin) {
-          $templ = preg_replace('/\bplugins\//', $this->config['plugins_dir'].'/', $templ);
+            $templ = preg_replace(array('/\bplugins\//', '/(["\']?)\/this\//'), array($this->app->plugins->url, '\\1'.$this->app->plugins->url.$skin_dir.'/'), $templ);
         }
 
         // parse for specialtags
@@ -374,7 +378,7 @@
             );
         }
         $output = $this->parse_with_globals($output);
-        $this->write(trim($output), $skin_path);
+        $this->write(trim($output));
         if ($exit) {
             exit;
         }
@@ -791,9 +795,6 @@
             }
             else if (in_array($attrib['command'], $a_static_commands)) {
                 $attrib['href'] = rcmail_url($attrib['command']);
-            }
-            else if ($attrib['command'] == 'permaurl' && !empty($this->env['permaurl'])) {
-                $attrib['href'] = $this->env['permaurl'];
             }
         }
 
@@ -357,9 +360,10 @@
         }
         
-        // replace all path references to plugins/... with the current plugins dir
+        // replace all path references to plugins/... with the configured plugins dir
+        // and /this/ to the current plugin skin directory
         if ($plugin) {

--
Gitblit v1.9.1